import { Component } from '@angular/core';
import { CommonModule } from '@angular/common';
import { Router, RouterModule } from '@angular/router';
import { FaIconComponent, FontAwesomeModule } from '@fortawesome/angular-fontawesome';
import { 
  faHome,
  faSearch,
  faComments,
  faUser
} from '@fortawesome/free-solid-svg-icons';

@Component({
  selector: 'app-nav-mobile-tabs',
  standalone: true,
  imports: [CommonModule, RouterModule, FontAwesomeModule, FaIconComponent],
  templateUrl: './nav-mobile-tabs.html',
  styleUrls: ['./nav-mobile-tabs.scss']
})
export class NavMobileTabs {
  // 导航图标
  icons = {
    home: faHome,
    search: faSearch,
    interview: faComments,
    mine: faUser
  };

  // 导航项配置
  navItems = [
    {
      icon: this.icons.home,
      label: '首页',
      route: '/home',
      active: false
    },
    {
      icon: this.icons.search,
      label: '职位',
      route: '/interview/mobile/page-job-hunting',
      active: false
    },
    {
      icon: this.icons.interview,
      label: '面试',
      route: '/interview/mobile/page-interview',
      active: false
    },
    {
      icon: this.icons.mine,
      label: '我的',
      route: '/interview/mobile/page-mine',
      active: false
    }
  ];

  constructor(private router: Router) {
    // 监听路由变化更新活动状态
    this.router.events.subscribe(() => {
      const currentRoute = this.router.url;
      this.navItems.forEach(item => {
        item.active = currentRoute.startsWith(item.route);
      });
    });
  }

  // 导航到指定路由
  navigateTo(route: string) {
    this.router.navigate([route]);
  }
}